==> go.php?file=PhoenixStyle1.53903.zip: PhoenixStyleMod_Firelands/Alysrazor.lua <==
﻿psbossfile53=1
function pscmrboss531(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables(name2)
		vezaxsort1()
end
end

function pscmrboss532(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables2(name2)
		vezaxsort2()
end
end

function pscmrboss533(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables3(name2)
		vezaxsort3()
end
end

function pscmrboss534(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables4(name2)
		vezaxsort4()
end
end

function pscmrboss535(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables5(name2)
		vezaxsort5()
end
end

function pscmrboss536(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables6(name2)
		vezaxsort6()
end
end

function pscmrboss537(guid2,name2)
--ptr test temp ыытест
if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables7(name2)
		vezaxsort7()
end
end


function pscmrbossREPORT531(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonboss53 and pswasonboss53==1) then

	if pswasonboss53==1 then
		pssetcrossbeforereport1=GetTime()
		if psraidoptionson[5][3][1]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[5][3][2]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][2]], true, vezaxname2, vezaxcrash2, 1)
		end
		if psraidoptionson[5][3][4]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][4]], true, vezaxname3, vezaxcrash3, 1)
		end
		if psraidoptionson[5][3][5]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99816|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][5]], true, vezaxname4, vezaxcrash4, 1)
		end
		if psraidoptionson[5][3][6]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99336|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][6]], true, vezaxname5, vezaxcrash5, 1)
		end
		if psraidoptionson[5][3][7]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98885|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][7]], true, vezaxname6, vezaxcrash6, 1)
		end
		if psraidoptionson[5][3][8]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99427|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][8]], true, vezaxname7, vezaxcrash7, 1)
		end



	end
	if pswasonboss53==1 or (pswasonboss53==2 and try==nil) then

		psiccsavinginf(psbossnames[5][3], try, pswasonboss53)

		strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
		reportafterboitwotab("raid", true, vezaxname3, vezaxcrash3, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99816|id: "
		reportafterboitwotab("raid", true, vezaxname4, vezaxcrash4, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99336|id: "
		reportafterboitwotab("raid", true, vezaxname5, vezaxcrash5, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id98885|id: "
		reportafterboitwotab("raid", true, vezaxname6, vezaxcrash6, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99427|id: "
		reportafterboitwotab("raid", true, vezaxname7, vezaxcrash7, nil, nil,0,1)

		psiccrefsvin()

	end




	if wipe then
		pswasonboss53=2
		pscheckbossincombatmcr=GetTime()+1
	end
end
end
end


function  pscmrbossRESET531(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonboss53=nil
table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
table.wipe(vezaxname3)
table.wipe(vezaxcrash3)
table.wipe(vezaxname4)
table.wipe(vezaxcrash4)
table.wipe(vezaxname5)
table.wipe(vezaxcrash5)
table.wipe(vezaxname6)
table.wipe(vezaxcrash6)
table.wipe(vezaxname7)
table.wipe(vezaxcrash7)
end
end


function pscombatlogboss53(...)
local arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15 = ...

if arg2=="SPELL_DAMAGE" and spellid==98463 then
pscmrboss531(guid2,name2)
end

if arg2=="SPELL_DAMAGE" and spellid==99844 then
pscmrboss532(guid2,name2)
end

if arg2=="SPELL_AURA_APPLIED" and spellid==100359 then
psunitisplayer(guid2,name2)
if psunitplayertrue then
else
	if psraidoptionson[5][3][3]==1 then
		SendChatMessage("{rt8} "..pscmrtxtoptt533..": "..name2, psraidchats3[psraidoptionschat[5][3][3]])
	end
end
end

if arg2=="SPELL_DAMAGE" and spellid==99794 then
pscmrboss533(guid2,name2)
end

if arg2=="SPELL_DAMAGE" and spellid==99816 then
pscmrboss534(guid2,name2)
end

if arg2=="SPELL_DAMAGE" and spellid==99336 then
pscmrboss535(guid2,name2)
end

if arg2=="SPELL_DAMAGE" and spellid==98885 then
pscmrboss536(guid2,name2)
end

if arg2=="SPELL_DAMAGE" and spellid==99427 then
pscmrboss537(guid2,name2)
end





--НАЙТИ Blazing Power 25 бафов дают:
--НАЙТИ Alysrazor






end

==> go.php?file=PhoenixStyle1.54001.zip: PhoenixStyleMod_Firelands/Alysrazor.lua <==
﻿psbossfile53=1
function pscmrboss531(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables(name2)
		vezaxsort1()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 1, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss532(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables2(name2)
		vezaxsort2()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 2, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss533(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables3(name2)
		vezaxsort3()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 3, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss534(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables4(name2)
		vezaxsort4()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 4, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss535(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables5(name2)
		vezaxsort5()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 5, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss536(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables6(name2)
		vezaxsort6()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 6, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss537(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables7(name2)
		vezaxsort7()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 7, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end


function pscmrbossREPORT531(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonboss53 and pswasonboss53==1) then

	if pswasonboss53==1 then
		pssetcrossbeforereport1=GetTime()
		if psraidoptionson[5][3][1]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[5][3][2]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][2]], true, vezaxname2, vezaxcrash2, 1)
		end
		if psraidoptionson[5][3][4]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][4]], true, vezaxname3, vezaxcrash3, 1)
		end
		if psraidoptionson[5][3][5]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99816|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][5]], true, vezaxname4, vezaxcrash4, 1)
		end
		if psraidoptionson[5][3][6]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99336|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][6]], true, vezaxname5, vezaxcrash5, 1)
		end
		if psraidoptionson[5][3][7]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98885|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][7]], true, vezaxname6, vezaxcrash6, 1)
		end
		if psraidoptionson[5][3][8]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99427|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][8]], true, vezaxname7, vezaxcrash7, 1)
		end



	end
	if pswasonboss53==1 or (pswasonboss53==2 and try==nil) then

		psiccsavinginf(psbossnames[5][3], try, pswasonboss53)

		strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
		reportafterboitwotab("raid", true, vezaxname3, vezaxcrash3, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99816|id: "
		reportafterboitwotab("raid", true, vezaxname4, vezaxcrash4, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99336|id: "
		reportafterboitwotab("raid", true, vezaxname5, vezaxcrash5, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id98885|id: "
		reportafterboitwotab("raid", true, vezaxname6, vezaxcrash6, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99427|id: "
		reportafterboitwotab("raid", true, vezaxname7, vezaxcrash7, nil, nil,0,1)

		psiccrefsvin()

	end




	if wipe then
		pswasonboss53=2
		pscheckbossincombatmcr=GetTime()+1
	end
end
end
end


function  pscmrbossRESET531(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonboss53=nil
table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
table.wipe(vezaxname3)
table.wipe(vezaxcrash3)
table.wipe(vezaxname4)
table.wipe(vezaxcrash4)
table.wipe(vezaxname5)
table.wipe(vezaxcrash5)
table.wipe(vezaxname6)
table.wipe(vezaxcrash6)
table.wipe(vezaxname7)
table.wipe(vezaxcrash7)
end
end


function pscombatlogboss53(...)
local arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15 = ...

if arg2=="SPELL_DAMAGE" and spellid==98463 then
pscmrboss531(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==99844 then
pscmrboss532(guid2,name2,spellname)
end

if arg2=="SPELL_AURA_APPLIED" and spellid==100359 then
psunitisplayer(guid2,name2)
if psunitplayertrue then
else
	if psraidoptionson[5][3][3]==1 then
		pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][3]], "{rt8} "..psfiretxtoptt533..": "..name2)
	end
end
end

if arg2=="SPELL_DAMAGE" and spellid==99794 then
pscmrboss533(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==99816 then
pscmrboss534(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==99336 then
pscmrboss535(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==98885 then
pscmrboss536(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==99427 then
pscmrboss537(guid2,name2,spellname)
end





--НАЙТИ Blazing Power 25 бафов дают:
--НАЙТИ Alysrazor






end
